@@ -39,19 +39,14 @@ Cmdline ()
 	for _PARAMETER in ${_CMDLINE}
 	do
 		case "${_PARAMETER}" in
-			live-config|config)
-				# Run all scripts
-				_SCRIPTS="$(ls /lib/live/config/*)"
-				;;
-
 			live-config=*|config=*)
 				# Only run requested scripts
 				LIVE_CONFIGS="${_PARAMETER#*config=}"
 				;;
 
-			live-noconfig|noconfig)
-				# Don't run any script
-				_SCRIPTS=""
+			live-config|config)
+				# Run all scripts
+				_SCRIPTS="$(ls /lib/live/config/*)"
 				;;
 
 			live-noconfig=*|noconfig=*)
@@ -60,25 +55,34 @@ Cmdline ()
 				LIVE_NOCONFIGS="${_PARAMETER#*noconfig=}"
 				;;
 
+			live-noconfig|noconfig)
+				# Don't run any script
+				_SCRIPTS=""
+				;;
+
 			# Shortcuts
 			live-config.noroot|noroot)
 				# Disable root access, no matter what mechanism
 				_SCRIPTS="${_SCRIPTS:-$(ls /lib/live/config/*)}"
 				LIVE_NOCONFIGS="${LIVE_NOCONFIGS},sudo,policykit"
 
-				_NO_ROOT="true"
+				_NOROOT="true"
 				;;
 
 			live-config.noautologin|noautologin)
 				# Disables both console and graphical autologin.
 				_SCRIPTS="${_SCRIPTS:-$(ls /lib/live/config/*)}"
 				LIVE_NOCONFIGS="${LIVE_NOCONFIGS},sysvinit,gdm,gdm3,kdm,lightdm,lxdm,nodm,slim,upstart,xinit"
+
+				_NOAUTOLOGIN="true"
 				;;
 
 			live-config.nottyautologin|nottyautologin)
 				# Disables console autologin.
 				_SCRIPTS="${_SCRIPTS:-$(ls /lib/live/config/*)}"
 				LIVE_NOCONFIGS="${LIVE_NOCONFIGS},sysvinit,upstart"
+
+				_NOTTYAUTOLOGIN="true"
 				;;
 
 			live-config.nox11autologin|nox11autologin)
@@ -86,6 +90,8 @@ Cmdline ()
 				# mechanism
 				_SCRIPTS="${_SCRIPTS:-$(ls /lib/live/config/*)}"
 				LIVE_NOCONFIGS="${LIVE_NOCONFIGS},gdm,gdm3,kdm,lightdm,lxdm,nodm,slim,xinit"
+
+				_NOX11AUTOLOGIN="true"
 				;;
 
 			# Special options
@@ -131,7 +137,7 @@ Trap ()
 	return ${_RETURN}
 }
 
-Start_network ()
+Setup_network ()
 {
 	if [ -z "${_NETWORK}" ] && [ -e /etc/init.d/live-config ]
 	then
@@ -169,9 +175,9 @@ Main ()
 	echo -n "live-config:"
 	trap 'Trap' EXIT HUP INT QUIT TERM
 
-	# Reading configuration file from filesystem and live-media
+	# Reading configuration files from filesystem and live-media
 	for _FILE in /etc/live/config.conf /etc/live/config/* \
-		     /lib/live/image/live/config.conf /lib/live/image/live/config/*
+		     /lib/live/mount/medium/live/config.conf /lib/live/mount/medium/live/config/*
 	do
 		if [ -e "${_FILE}" ]
 		then
@@ -179,7 +185,7 @@ Main ()
 		fi
 	done
 
-	# Reading kernel command line
+	# Processing command line
 	Cmdline
 
 	case "${LIVE_DEBUG}" in
@@ -195,7 +201,7 @@ Main ()
 
 	for _SCRIPT in ${_SCRIPTS}
 	do
-		[ "${_LIVE_DEBUG}" = "true" ] && echo "[$(date +'%F %T')] live-config: ${_SCRIPT}" >> /var/log/live/config.log
+		[ "${LIVE_DEBUG}" = "true" ] && echo "[$(date +'%F %T')] live-config: ${_SCRIPT}" >> /var/log/live/config.log
 
 		. ${_SCRIPT} 2>&1 | tee -a /var/log/live/config.log
 	done
@@ -203,4 +209,4 @@ Main ()
 	echo "."
 }
 
-Main
+Main ${@}
